@@ -14,6 +14,7 @@ import matplotlib.pylab as plt
 import matplotlib.patches as patches
 
 from pyTEMlib import file_tools as ft
+
 import sidpy
 
 _version = 000
@@ -22,6 +23,8 @@ _version = 000
 class EELSDialog(QtWidgets.QDialog):
     """
     EELS Input Dialog for Chemical Analysis
+
+
     """
 
     def __init__(self, dataset=None):
@@ -72,9 +75,10 @@ class EELSDialog(QtWidgets.QDialog):
             self.axis = self.dataset.view.axes[-1]
         elif hasattr(self.dataset.view, 'axis'):
             self.axis = self.dataset.view.axis
-        self.spectrum_plot = CurveVisualizer(self.dataset, axis=self.axis)
+
         self.figure = self.axis.figure
-        self.cid = self.figure.canvas.mpl_connect('draw_event', self.plot)
+        self.updY = 0
+        self.figure.canvas.mpl_connect('button_press_event', self.plot)
 
         self.plot()
         self.ui.edit4.setFocus()
@@ -86,15 +90,13 @@ class EELSDialog(QtWidgets.QDialog):
             self.dataset.metadata['edges'] = {'0': {}, 'model': {}}
         self.edges = self.dataset.metadata['edges']
 
-        spec_dim = -1
-        for dim, axis in dataset._axes.items():
-            if axis.dimension_type == sidpy.DimensionType.SPECTRAL:
-                spec_dim = dim
-        if spec_dim < 0:
+        spec_dim = ft.get_dimensions_by_type('spectral', dataset)[0]
+
+        if len(spec_dim) == 0:
             raise TypeError('We need at least one SPECTRAL dimension')
 
-        self.spec_dim = spec_dim
-        self.energy_scale = dataset._axes[spec_dim].values
+        self.spec_dim = spec_dim[0]
+        self.energy_scale = dataset._axes[self.spec_dim].values
         self.ui.edit2.setText(f"{self.energy_scale[-2]:.3f}")
 
         if 'fit_area' not in self.edges:
@@ -110,6 +112,14 @@ class EELSDialog(QtWidgets.QDialog):
         else:
             self.ui.edit2.setText(f"{self.edges['fit_area']['fit_end']:.3f}")
 
+        if self.dataset.data_type.name == 'SPECTRAL_IMAGE':
+            if 'SI_bin_x' not in self.dataset.metadata['experiment']:
+                self.dataset.metadata['experiment']['SI_bin_x'] = 1
+                self.dataset.metadata['experiment']['SI_bin_y'] = 1
+
+            bin_x = self.dataset.metadata['experiment']['SI_bin_x']
+            bin_y = self.dataset.metadata['experiment']['SI_bin_y']
+            self.dataset.view.set_bin([bin_x, bin_y])
         self.update()
 
     def update(self):
@@ -270,7 +280,7 @@ class EELSDialog(QtWidgets.QDialog):
         edge_list.setCurrentIndex(index)
         self.update()
 
-    def plot(self):
+    def plot(self, event=None):
         self.energy_scale = self.dataset._axes[self.spec_dim].values
         if self.dataset.data_type == sidpy.DataType.SPECTRAL_IMAGE:
             spectrum = self.dataset.view.get_spectrum()
@@ -462,7 +472,62 @@ class EELSDialog(QtWidgets.QDialog):
         self.plot()
 
     def do_all_button_click(self):
-        pass
+
+        if self.dataset.data_type.name != 'SPECTRAL_IMAGE':
+            self.do_fit_button_click()
+            return
+
+        if 'experiment' in self.dataset.metadata:
+            exp = self.dataset.metadata['experiment']
+            if 'convergence_angle' not in exp:
+                raise ValueError('need a convergence_angle in experiment of metadata dictionary ')
+            alpha = exp['convergence_angle']
+            beta = exp['collection_angle']
+            beam_kv = exp['acceleration_voltage']
+        else:
+            raise ValueError('need a experiment parameter in metadata dictionary')
+
+        self.energy_scale = self.dataset._axes[self.spec_dim].values
+        eff_beta = eels.effective_collection_angle(self.energy_scale, alpha, beta, beam_kv)
+        edges = eels.make_cross_sections(self.edges, np.array(self.energy_scale), beam_kv, eff_beta)
+
+        view = self.dataset.view
+        bin_x = view.bin_x
+        bin_y = view.bin_y
+
+        start_x = view.x
+        start_y = view.y
+
+        number_of_edges = 0
+        for key in self.edges:
+            if key.isdigit():
+                number_of_edges += 1
+
+
+        results = np.zeros([int(self.dataset.shape[0]/bin_x), int(self.dataset.shape[1]/bin_y), number_of_edges])
+        total_spec = int(self.dataset.shape[0]/bin_x)*int(self.dataset.shape[1]/bin_y)
+        self.ui.progress.setMaximum(total_spec)
+        self.ui.progress.setValue(0)
+        ind = 0
+        for x in range (int(self.dataset.shape[0]/bin_x)):
+
+            for y in range(int(self.dataset.shape[1]/bin_y)):
+                ind +=1
+                self.ui.progress.setValue(ind)
+                view.x = x*bin_x
+                view.y = y*bin_y
+                spectrum = view.get_spectrum()
+
+                edges = eels.fit_edges2(spectrum, self.energy_scale, edges)
+                for key, edge in edges.items():
+                    if key.isdigit():
+                        # element.append(edge['element'])
+                        results[x,y, int(key)] = edge['areal_density']
+        edges['spectrum_image_quantification'] = results
+        self.ui.progress.setValue(total_spec)
+        view.x = start_x
+        view.y = start_y
+
 
     def do_fit_button_click(self):
         if 'experiment' in self.dataset.metadata:
@@ -544,7 +609,10 @@ class CurveVisualizer(object):
         self.plot(**kwargs)
 
     def plot(self, **kwargs):
-        line1, = self.axis.plot(self.energy_scale.values, self.dset, label='spectrum', **kwargs)
+        if self.dset.data_type.name == 'IMAGE_STACK':
+            line1, = self.axis.plot(self.energy_scale.values, self.dset[0, 0], label='spectrum', **kwargs)
+        else:
+            line1, = self.axis.plot(self.energy_scale.values, self.dset, label='spectrum', **kwargs)
         lines = [line1]
         if 'add2plot' in self.dset.metadata:
             data = self.dset.metadata['add2plot']
